using System;
using UnityEngine;
using System.Collections;
using System.Collections.Generic;
using System.Text;
using SimpleJSON;
using System.Linq;
using MVR;
using MeshVR;
using Unity.Collections;
using AssetBundles;

namespace Stopper {
	public class DisableTextureCompression : MVRScript {
        MonoBehaviour originalImageLoader = null;
        MonoBehaviour imageLoaderNoCompression = null;
        
        public override void Init() {
			originalImageLoader = ImageLoaderThreaded.singleton;
            
            ImageLoaderThreaded.singleton.PurgeAllTextures();
			imageLoaderNoCompression = originalImageLoader.gameObject.AddComponent<ImageLoaderThreadedNoCompression>();
		}

        private void OnEnable() {
            if(imageLoaderNoCompression != null){
                ImageLoaderThreaded.singleton.PurgeAllTextures();
                ImageLoaderThreaded.singleton = imageLoaderNoCompression as ImageLoaderThreadedNoCompression;
            }
        }
		
		
		private void OnDisable() {
            if(originalImageLoader != null) {
                ImageLoaderThreaded.singleton.PurgeAllTextures();
                ImageLoaderThreaded.singleton = originalImageLoader as ImageLoaderThreaded;
            }
		}

        private void OnDestroy() {
            if(imageLoaderNoCompression != null) {
                Destroy(imageLoaderNoCompression);
            }
        }

        public class ImageLoaderThreadedNoCompression : ImageLoaderThreaded {

            // Copied from VAM's ImageLoaderThreaded code
            private void Update() {
                this.StartThreads();
                if (!this.imageLoaderTask.working) {
                    
                    this.PostProcessImageQueue();
                    if (this.queuedImages != null && this.queuedImages.Count > 0)
                    {
                        this.queuedImages.First.Value.compress = false;
                        this.PreprocessImageQueue();
                        this.imageLoaderTask.working = true;
                        this.imageLoaderTask.resetEvent.Set();
                    }
                }
            }
        }
	}
}